@@ -16,7 +16,7 @@ use GD::Polygon;
 
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $AUTOLOAD);
 
-$VERSION = '2.56_02';
+$VERSION = '2.56_03';
 our $XS_VERSION = $VERSION;
 $VERSION = eval $VERSION;
 
@@ -462,6 +462,8 @@ support.
 NOTE: The libgd library is unable to read certain XPM files, returning
 an all-black image instead.
 
+=back
+
 =head1 GD::Image Methods
 
 Once a GD::Image object is created, you can draw with it, copy it, and
@@ -474,6 +476,8 @@ a file.
 The following methods convert the internal drawing format into
 standard output file formats.
 
+=over
+
 =item B<$pngdata = $image-E<gt>png([$compression_level])>
 
 This returns the image data in PNG format.  You can then print it,
@@ -694,6 +698,16 @@ Example:
 This returns a list containing the red, green and blue components of
 the specified color index.
 
+Example:
+
+	@RGB = $myImage->rgb($peachy);
+
+
+=item B<($alpha) = $image-E<gt>alpha($index)>
+
+This returns an item containing the alpha component of the specified
+color index.
+
 Example:
 
 	@RGB = $myImage->rgb($peachy);
